function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import Toast from "./../../Toast";
import locale from "./../../locale"; // eslint-disable-next-line

export default {
  // ranges分成两部分: quickRanges(快捷选择)和customRanges(自定义选择)
  getRanges: function getRanges(ranges) {
    var quickRanges = {};
    var customRanges = {};

    if (toString.call(ranges) === '[object Object]' && !Object.isEmptyObject(ranges)) {
      for (var rangeKey in ranges) {
        var rangeValue = ranges[rangeKey];

        if (Array.isArray(rangeValue) && rangeValue.length === 2 && rangeValue[0] instanceof Date && rangeValue[1] instanceof Date) {
          quickRanges[rangeKey] = rangeValue;
        } else {
          // 自定义选择只能有一个
          customRanges = _defineProperty({}, rangeKey, rangeValue);
        }
      }
    } else {
      if (typeof ranges === 'number') {
        customRanges = _defineProperty({}, locale('自定义时间', 'datepicker-tooltip_custom_date'), ranges);
      }
    }

    return {
      quickRanges: quickRanges,
      customRanges: customRanges
    };
  },
  // 开始结束时间
  getDates: function getDates(value) {
    if (!Array.isArray(value) || value.length !== 2) {
      return {
        startDate: null,
        endDate: null
      };
    }

    var startDate = value[0] instanceof Date ? value[0] : null;
    var endDate = value[1] instanceof Date ? value[1] : null;
    return {
      startDate: startDate,
      endDate: endDate
    };
  },
  // 判断是否开始时间大于结束时间
  validateTime: function validateTime(value, config) {
    var _this$getDates = this.getDates(value),
        startDate = _this$getDates.startDate,
        endDate = _this$getDates.endDate;

    if (!startDate || !endDate) {
      return true;
    }

    var type = config.type,
        onError = config.onError;
    var errMsg = '';

    if (type === 'year' && endDate.compareYear(startDate) === -1) {
      errMsg = locale('开始时间不能大于结束时间', 'hint_start_greater_end_time');
    } else if (type === 'quarter' && endDate.compareMonth(startDate) === -1) {
      errMsg = locale('开始时间不能大于结束时间', 'hint_start_greater_end_time');
    } else if (type === 'month' && endDate.compareMonth(startDate) === -1) {
      errMsg = locale('开始时间不能大于结束时间', 'hint_start_greater_end_time');
    } else if (type === 'date' && endDate.compareDate(startDate) === -1) {
      errMsg = locale('开始时间不能大于结束时间', 'hint_start_greater_end_time');
    } else if (type === 'datetime' && endDate.compareDateTime(startDate) === -1) {
      errMsg = locale('开始时间不能大于结束时间', 'hint_start_greater_end_time');
    } else if (type === 'time' && endDate.compareTime(startDate) === -1) {
      errMsg = locale('开始时间不能大于结束时间', 'hint_start_greater_end_time');
    } // 有错误


    if (errMsg) {
      if (onError) {
        onError({
          errMsg: errMsg,
          value: value
        });
      } else {
        Toast.show({
          content: errMsg
        });
      }

      return false;
    }

    return true;
  },
  // 计算区间, 区间内
  validateDays: function validateDays(value, _ref) {
    var daysLimit = _ref.daysLimit,
        onError = _ref.onError;
    if (!daysLimit) return true;

    var _this$getDates2 = this.getDates(value),
        startDate = _this$getDates2.startDate,
        endDate = _this$getDates2.endDate;

    if (!startDate || !endDate) {
      return true;
    }

    var diff = startDate.diff(endDate);

    if (diff.days > daysLimit) {
      var errMsg = locale("\u81EA\u5B9A\u4E49\u65F6\u95F4\u533A\u95F4\u4E0D\u80FD\u8D85\u8FC7".concat(daysLimit, "\u5929"), 'hint_error_datepopover_custom_date_range_timeout', [daysLimit]);

      if (onError) {
        onError({
          errMsg: errMsg,
          daysLimit: daysLimit,
          value: value
        });
      } else {
        Toast.show({
          content: errMsg
        });
      }

      return false;
    }

    return true;
  }
};